@@ -188,9 +188,9 @@ int main(int argc, char *argv[]){
                                         }
                                       }
                                       result_accumulation = "";
-                                      if (character != '\r'){
-                                        fwrite(&character, sizeof(character), 1, stdout );
-                                      }
+                                      // if (character != '\r'){
+                                      //   fwrite(&character, sizeof(character), 1, stdout );
+                                      // }
 
                                     }
                                     
